==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ForceIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { ForceIndexIndicatorDescription } from "./ForceIndexIndicatorDescription";
/**
 * @hidden
 */
var ForceIndexIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ForceIndexIndicatorDescriptionMetadata, _super);
    function ForceIndexIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ForceIndexIndicatorDescriptionMetadata.b = function (a) {
        if (ForceIndexIndicatorDescriptionMetadata.a == null) {
            ForceIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ForceIndexIndicatorDescriptionMetadata.c(ForceIndexIndicatorDescriptionMetadata.a);
        }
        if (a.g(ForceIndexIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(ForceIndexIndicatorDescriptionMetadata.a);
    };
    ForceIndexIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    ForceIndexIndicatorDescriptionMetadata.d = function (a) {
        ForceIndexIndicatorDescriptionMetadata.b(a);
        a.u("ForceIndexIndicator", function () { return new ForceIndexIndicatorDescription(); });
        a.t("ForceIndexIndicator", ForceIndexIndicatorDescriptionMetadata.a);
    };
    ForceIndexIndicatorDescriptionMetadata.$t = markType(ForceIndexIndicatorDescriptionMetadata, 'ForceIndexIndicatorDescriptionMetadata');
    ForceIndexIndicatorDescriptionMetadata.a = null;
    return ForceIndexIndicatorDescriptionMetadata;
}(Base));
export { ForceIndexIndicatorDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ForceIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { ForceIndexIndicatorDescription } from "./ForceIndexIndicatorDescription";
/**
 * @hidden
 */
var ForceIndexIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ForceIndexIndicatorDescriptionMetadata, _super);
    function ForceIndexIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ForceIndexIndicatorDescriptionMetadata.b = function (a) {
        if (ForceIndexIndicatorDescriptionMetadata.a == null) {
            ForceIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ForceIndexIndicatorDescriptionMetadata.c(ForceIndexIndicatorDescriptionMetadata.a);
        }
        if (a.j(ForceIndexIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(ForceIndexIndicatorDescriptionMetadata.a);
    };
    ForceIndexIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    ForceIndexIndicatorDescriptionMetadata.d = function (a) {
        ForceIndexIndicatorDescriptionMetadata.b(a);
        a.aa("ForceIndexIndicator", function () { return new ForceIndexIndicatorDescription(); });
        a.z("ForceIndexIndicator", ForceIndexIndicatorDescriptionMetadata.a);
    };
    ForceIndexIndicatorDescriptionMetadata.$t = markType(ForceIndexIndicatorDescriptionMetadata, 'ForceIndexIndicatorDescriptionMetadata');
    ForceIndexIndicatorDescriptionMetadata.a = null;
    return ForceIndexIndicatorDescriptionMetadata;
}(Base));
export { ForceIndexIndicatorDescriptionMetadata };
